﻿using HardwareShopContracts.BindingModels;
using HardwareShopContracts.ViewModels;
using HardwareShopDatabaseImplement.Models;
using HardwareShopDataModels.Enums;
using HardwareShopWorkerApp.Models;
using Microsoft.AspNetCore.Mvc;
using System.Diagnostics;

namespace HardwareShopWorkerApp.Controllers
{
    public class HomeController : Controller
    {
        private readonly ILogger<HomeController> _logger;

        public HomeController(ILogger<HomeController> logger)
        {
            _logger = logger;
        }

        public IActionResult Register()
        {
            return View();
        }

        [HttpPost]
        public void Register(string login, string email, string password)
        {
            if (string.IsNullOrEmpty(login) || string.IsNullOrEmpty(email) || string.IsNullOrEmpty(password))
            {
                throw new Exception("Введите логин, email, пароль");
            }
            APIClient.PostRequest("api/user/register", new UserBindingModel
            {
                Login = login,
                Email = email,
                Password = password,
                Role = UserRole.Работник,
            });
            Response.Redirect("Enter");
            return;
        }

        public IActionResult Index()
        {
			if (APIClient.User == null)
			{
				return Redirect("~/Home/Enter");
			}
			return View();
		}

        public IActionResult Privacy()
        {
            return View();
        }

        [ResponseCache(Duration = 0, Location = ResponseCacheLocation.None, NoStore = true)]
        public IActionResult Error()
        {
            return View(new ErrorViewModel { RequestId = Activity.Current?.Id ?? HttpContext.TraceIdentifier });
        }

        public IActionResult Enter()
        {
            return View();
        }

        [HttpPost]
        public void Enter(string email, string password)
        {
            if (string.IsNullOrEmpty(email) || string.IsNullOrEmpty(password))
            {
                throw new Exception("Введите почту и пароль");
            }
            APIClient.User = APIClient.GetRequest<UserViewModel>($"api/user/login?email={email}&password={password}");
            if (APIClient.User == null)
            {
                throw new Exception("Неверные почта и/или пароль");
            }
            Response.Redirect("MainWorker");
        }

        [HttpPost]
		public void CreateBuild(string name)
        {
            if (APIClient.User == null)
            {
                throw new Exception("Вы как суда попали? Суда вход только авторизованным");
            }
            if (string.IsNullOrEmpty(name))
            {
                throw new Exception($"Имя магазина не должно быть пустым");
            }
            APIClient.PostRequest("api/build/create", new BuildBindingModel
            {
				BuildName = name,
				UserId = APIClient.User.Id
			});
            Response.Redirect("Builds");
        }

		[HttpPost]
		public void UpdateBuild(string name)
		{
			if (APIClient.User == null)
			{
				throw new Exception("Вы как суда попали? Суда вход только авторизованным");
			}
			if (string.IsNullOrEmpty(name))
			{
				throw new Exception($"Имя магазина не должно быть пустым");
			}
			APIClient.PostRequest("api/build/update", new BuildBindingModel
			{
				BuildName = name,
				UserId = APIClient.User.Id
			});
			Response.Redirect("Builds");
		}

		public IActionResult MainWorker()
        {
            return View();
        }

        public IActionResult Comments()
        {
            return View();
        }

        public IActionResult listComponents()
        {
            return View();
        }

        [HttpGet]
        public IActionResult Purchases()
        {
            return View();
        }

        [HttpPost]
        public void Purchases(int id)
        {
            Response.Redirect("Purchase");
        }


        [HttpGet]
        public IActionResult Purchase()
        {
            return View();
        }

        public IActionResult WorkerReport()
        {
            return View();
        }

        [HttpGet]
        public IActionResult Builds()
        {
			if (APIClient.User == null)
			{
				return Redirect("~/Home/Enter");
			}
			return View(APIClient.GetRequest<List<BuildViewModel>>($"api/build/getbuilds?userId={APIClient.User.Id}"));
		}

        [HttpPost]
        public void Builds(int id)
        {
            Response.Redirect("LinkPurchase");
        }

        [HttpGet]
        public IActionResult LinkPurchase()
        {
            return View();
        }
    }
}